@@ -26,6 +26,7 @@
 #' @param yname.formula Name of y in the equation
 #' @param fontfamily Font family
 #' @param comment Add text after equation
+#' @param print.on Print output
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details
 #' The Avhad e Marchetti model is defined by:
@@ -66,7 +67,8 @@ AM=function(trat,
             xname.formula="x",
             yname.formula="y",
             comment=NA,
-            fontfamily="sans"){
+            fontfamily="sans",
+            print.on=TRUE){
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   requireNamespace("ggplot2")
   ymean=tapply(resp,trat,mean)
@@ -119,7 +121,7 @@ AM=function(trat,
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
                                                  width=width.bar,
-                                                 size=linesize)}
+                                                 linewidth=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
@@ -128,7 +130,7 @@ AM=function(trat,
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
 
   graph=graph+theme+geom_line(data=preditos,aes(x=x,
-                                                y=y,color="black"),size=linesize,lty=linetype)+
+                                                y=y,color="black"),linewidth=linesize,lty=linetype)+
     scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black", family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
@@ -165,6 +167,15 @@ AM=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
+
 }
