@@ -25,6 +25,7 @@
 #' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @param fontfamily Font family
+#' @param print.on Print output
 #'
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); breakpoint and the graph using ggplot2 with the equation automatically.
 #' @export
@@ -69,7 +70,8 @@ linear.plateau=function(trat,resp,
                       xname.formula="x",
                       yname.formula="y",
                       comment=NA,
-                      fontfamily="sans"){
+                      fontfamily="sans",
+                      print.on=TRUE){
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   lp <- function(x, a, b, c) {
     if_else(condition = x < c,
@@ -143,7 +145,7 @@ linear.plateau=function(trat,resp,
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
                                                  width=width.bar,
-                                                 size=linesize)}
+                                                 linewidth=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
@@ -160,7 +162,7 @@ linear.plateau=function(trat,resp,
   graph=graph+theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=linesize,lty=linetype)+
+                                color="black"),linewidth=linesize,lty=linetype)+
     scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
@@ -193,6 +195,14 @@ linear.plateau=function(trat,resp,
                                rmse))
   graficos=list("Coefficients segmented"=model2,
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
 }
