@@ -21,7 +21,7 @@
 adjust_scale_y=function(plots,
                         scale="default",
                         limits="default"){
-  if(length(plots)==3 | length(plots)==3){plots=plots[[3]]}else{plots=plots}
+  if(length(plots)==3 | length(plots)==4){plots=plots$plot}else{plots=plots}
   requireNamespace("ggplot2")
   if(limits[1]=="default"){limits=c(min(plots$plot$data$y),
                                     max(plots$plot$data$y))}
