@@ -25,6 +25,7 @@
 #' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @param fontfamily Font family
+#' @param print.on Print output
 #' @importFrom stats var
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details The model analogous to the three-parameter Gaussian is:
@@ -64,7 +65,8 @@ gaussianreg=function(trat,
                     xname.formula="x",
                     yname.formula="y",
                     comment=NA,
-                    fontfamily="sans"){
+                    fontfamily="sans",
+                    print.on=TRUE){
   requireNamespace("ggplot2")
   requireNamespace("drc")
   ymean=tapply(resp,trat,mean)
@@ -256,6 +258,14 @@ gaussianreg=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
 }
