@@ -26,6 +26,7 @@
 #' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @param fontfamily Font family
+#' @param print.on Print output
 #' @import purrr
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); breakpoint and the graph using ggplot2 with the equation automatically.
 #' @details
@@ -73,7 +74,8 @@ linear.linear=function (trat,
                         xname.formula="x",
                         yname.formula="y",
                     comment=NA,
-                    fontfamily="sans"){
+                    fontfamily="sans",
+                    print.on=TRUE){
   requireNamespace("ggplot2")
   requireNamespace("purrr")
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
@@ -183,7 +185,7 @@ linear.linear=function (trat,
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
                                                  width=width.bar,
-                                                 size=linesize)}
+                                                 linewidth=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
@@ -191,7 +193,7 @@ linear.linear=function (trat,
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   graph=graph+theme+
-    geom_line(data=preditos1,aes(x=x,y=y,color="black"),size=linesize,lty=linetype)+
+    geom_line(data=preditos1,aes(x=x,y=y,color="black"),linewidth=linesize,lty=linetype)+
     scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
@@ -225,6 +227,14 @@ linear.linear=function (trat,
                                rmse))
   graficos=list("Coefficients"=summary(mod$model),
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
 }
