@@ -32,6 +32,7 @@
 #' @param b Linear term
 #' @param c Quadratic term
 #' @param fontfamily Font family
+#' @param print.on Print output
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details
 #' The Plateau-quadratic model is defined by:
@@ -65,7 +66,6 @@
 #' attach(granada)
 #' x=time[length(time):1]
 #' plateau.quadratic(x,WL)
-#' @rdname plateau.quadratic
 #' @export
 
 plateau.quadratic=function(trat,
@@ -91,7 +91,8 @@ plateau.quadratic=function(trat,
                            yname.formula="y",
                            xname.formula="x",
                            comment=NA,
-                           fontfamily="sans"){
+                           fontfamily="sans",
+                           print.on=TRUE){
   requireNamespace("minpack.lm")
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   requireNamespace("dplyr")
@@ -156,7 +157,7 @@ plateau.quadratic=function(trat,
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
                                                  width=width.bar,
-                                                 size=linesize)}
+                                                 linewidth=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
@@ -173,7 +174,7 @@ plateau.quadratic=function(trat,
   graph=graph+theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=linesize,lty=linetype)+
+                                color="black"),linewidth=linesize,lty=linetype)+
     scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
@@ -207,8 +208,16 @@ plateau.quadratic=function(trat,
                                rmse))
   graficos=list("Coefficients"=model2,
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
 }
 
 
