@@ -25,6 +25,7 @@
 #' @param yname.formula Name of y in the equation
 #' @param comment Add text after equation
 #' @param fontfamily Font family
+#' @param print.on Print output
 #' @details
 #' The Yield Loss model is defined by:
 #' \deqn{y = \frac{i \times x}{1+\frac{i}{A} \times x}}
@@ -63,7 +64,8 @@ yieldloss=function(trat,
             xname.formula="x",
             comment=NA,
             scale="none",
-            fontfamily="sans"){
+            fontfamily="sans",
+            print.on=TRUE){
   requireNamespace("ggplot2")
   requireNamespace("drc")
   if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
@@ -140,7 +142,7 @@ yieldloss=function(trat,
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
                                                  width=width.bar,
-                                                 size=linesize)}
+                                                 linewidth=linesize)}
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   if(point=="all"){
@@ -148,7 +150,7 @@ yieldloss=function(trat,
     graph=graph+
       geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill=fillshape)}
   graph=graph+theme+
-    geom_line(data=preditos,aes(x=x,y=y,color="black"),size=linesize,lty=linetype)+
+    geom_line(data=preditos,aes(x=x,y=y,color="black"),linewidth=linesize,lty=linetype)+
     scale_color_manual(name="",values=colorline,label=parse(text = equation))+
     theme(axis.text = element_text(size=textsize,color="black",family = fontfamily),
           axis.title = element_text(size=textsize,color="black",family = fontfamily),
@@ -176,6 +178,14 @@ yieldloss=function(trat,
                                rmse))
   graficos=list("Coefficients"=coef,
                 "values"=graphs,
-                "plot"=graph)
-  graficos
+                "plot"=graph,
+                "expression"=s,
+                "xaxisp"=temp1,
+                "yaxisp"=result,
+                "trt"=trat,
+                "resp"=resp,
+                "desvio"=desvio,
+                "model"=model)
+  if(print.on==TRUE){print(graficos[1:3])}
+  output=graficos
 }
